"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createIsAuthenticatedTypeDef = exports.createIsAuthenticatedDirective = void 0;
const graphql_tools_1 = require("graphql-tools");
const graphql_1 = require("graphql");
const errors_1 = require("./errors");
const graphql_tag_1 = __importDefault(require("graphql-tag"));
const createIsAuthenticatedDirective = (checkIsAuthenticated) => {
    return class extends graphql_tools_1.SchemaDirectiveVisitor {
        visitFieldDefinition(field) {
            const { resolve = graphql_1.defaultFieldResolver } = field;
            field.resolve = (...args) => __awaiter(this, void 0, void 0, function* () {
                const context = args[2];
                const isAuthenticated = yield this._resolveIsAuthenticated(context);
                if (!isAuthenticated) {
                    throw new errors_1.AuthenticationError('You need to be authenticated to access this field');
                }
                return resolve.apply(this, args);
            });
        }
        _resolveIsAuthenticated(context) {
            if (checkIsAuthenticated) {
                return checkIsAuthenticated(context);
            }
            return context === null || context === void 0 ? void 0 : context.isAuthenticated;
        }
    };
};
exports.createIsAuthenticatedDirective = createIsAuthenticatedDirective;
const createIsAuthenticatedTypeDef = (name = 'isAuthenticated') => (graphql_tag_1.default `
    """
    Checks if user is authenticated.
    """
    directive @${name} on FIELD_DEFINITION
    `);
exports.createIsAuthenticatedTypeDef = createIsAuthenticatedTypeDef;
//# sourceMappingURL=index.js.map